@@ -264,4 +264,14 @@ summary.phmm <-
 	   Std.Error = sqrt(ifelse(diag(object$var)<0, NA, diag(object$var)))[1:object$nfixed])
 	class(object)<-"summary.phmm"
 	return(object)
+}
+
+plot.phmm <-
+ function(x, ...)
+{
+	x = as.data.frame(x$steps)
+	colnames(x) = make.names(colnames(x))
+	fm = paste(paste(colnames(x), collapse=' + '), "EM.Step", sep=" ~ ")
+	x$EM.Step = as.numeric(rownames(x))
+	xyplot(formula(fm), data=x, type="l", allow.multiple=TRUE, outer=TRUE, scales="free", ...)
 }
\ No newline at end of file
